@@ -24,11 +24,12 @@ int TestSOPClassUIDToIOD(int, char *[])
   std::cout << s[1] << std::endl;
   if( std::string(s[1] ) != "Basic Directory IOD Modules" ) return 1;
 
-  gdcm::SOPClassUIDToIOD::SOPClassUIDToIODType& s2 = gdcm::SOPClassUIDToIOD::GetSOPClassUIDToIOD(103);
-  std::cout << ( s2[0] == 0 ) << std::endl;
-  if( !(s2[0] == 0) ) return 1;
-  std::cout << ( s2[1] == 0 ) << std::endl;
-  if( !(s2[1] == 0) ) return 1;
+  // points to { nullptr, nullptr }, hardcoded
+  gdcm::SOPClassUIDToIOD::SOPClassUIDToIODType& s2 = gdcm::SOPClassUIDToIOD::GetSOPClassUIDToIOD(105);
+  std::cout << ( s2[0] == nullptr ) << std::endl;
+  if( !(s2[0] == nullptr) ) return 1;
+  std::cout << ( s2[1] == nullptr ) << std::endl;
+  if( !(s2[1] == nullptr) ) return 1;
 
   const char *sopclassuid = gdcm::SOPClassUIDToIOD::GetSOPClassUIDFromIOD( s[1] );
   const char *iod = gdcm::SOPClassUIDToIOD::GetIODFromSOPClassUID( s[0] );
